#include <Wire.h>
#include "time.h"
#include "timeanalog.h"
#include "touchbuttons.h"
#include "display.h"
#include "character.h"
#include "credits.h"
#include "DHT.h"

Chronodot RTC;

#define UPDATE_RATE_SETTING_TIME 250 
#define DHTPIN 6     // what pin we're connected to ( Digital Pin 6) //jason
#define DHTTYPE DHT11   // DHT 11  (AM2302) //jason
DHT dht1(DHTPIN, DHTTYPE); //// Initialize DHT sensor for normal 16mhz Arduino //jason


byte h, m, s, tem;  // jason added tem for temp

byte timeMode = TIME_MODE_NORMAL;

boolean blink = true; // Used to blink the colon or the hour/minute

void timeManager(unsigned long now, boolean modeChanged)
{
  static unsigned long prev;
 
  if (timeMode == TIME_MODE_NORMAL) // Do not change mode when setting time
  {
    // Change global mode when top buttons pressed
    if (TL_KEY_DOWN)
    {
      goToPrevMode();
      return;
    }
    if (TR_KEY_DOWN)
    {
      goToNextMode();
      return;
    }
    
    // Enter setting time mode when pressing either buttons
    if ((BL_KEY_DOWN && BR_KEY_PRESSED ||
         BR_KEY_DOWN && BL_KEY_PRESSED ) &&
         displayMode == MODE_DIGITAL_CLOCK) // Allow to set time only in digital mode
    {
      timeMode = TIME_MODE_SETTING_HOUR;
      return;
    }
  }
  else //timeMode != TIME_MODE_NORMAL (Setting time)
  {
    // Exit setting time mode when pressing right bottom button
    if (BR_KEY_DOWN)
    {
      s=0;  //Brett set seconds to 0 in time setting mode BR pressed
      updateRTCtime();
      //timeMode = TIME_MODE_NORMAL;
      return;
    }
  }
  
  // Proceed only if just entered this mode or if interval has passed or if setting time
  if (!modeChanged && now-prev < TIME_INTERVAL && timeMode == TIME_MODE_NORMAL)
    return;
   //prev = now; // done below
  
  if (timeMode == TIME_MODE_NORMAL)
  {
    // Get the time from the RTC
    getRTCtime();
    //DEBUG
    /*m++;
    if (m == 60)
    {
      m=0;
      h++;
      if (h == 24)
        h=0;
    }
    */
  }
  else //timeMode != TIME_MODE_NORMAL (Setting time)
  {
    if (BL_KEY_DOWN) // Bottom left button pressed
    {
      if (timeMode == TIME_MODE_SETTING_HOUR) // Finish setting hour, switch to setting minute
      {
        timeMode = TIME_MODE_SETTING_MINUTE;
      }
      else // Finish setting minute, update RTC
      {
        updateRTCtime();
        timeMode = TIME_MODE_NORMAL;
      }  
    }
    else if (TL_KEY_DOWN) // Top left button pressed
    {
       // Decrement hour or minute
       if (timeMode == TIME_MODE_SETTING_HOUR)
       {  
          if (h == 0) h = 23;
          else h--;
       }
       else //timeMode == TIME_MODE_SETTING_MINUTE
       {
          if (m == 0) m = 59;
          else m--;
       }
       blink = true;
    }
    else if (TR_KEY_DOWN)  // Top right button pressed
    {
       // Increment hour or minute
       if (timeMode == TIME_MODE_SETTING_HOUR)
       {  
          if (h == 23) h = 0;
          else h++;
          }
       else //timeMode == TIME_MODE_SETTING_MINUTE
       {
          if (m == 59) m = 0;
          else m++;
       }
       blink = true;
    }




  }
   
  // Show the time on the display
  if (now-prev < UPDATE_RATE_SETTING_TIME && timeMode != TIME_MODE_NORMAL) // Hack to avoid seizure-inducing blinking when setting time
    return;
  prev = now;
  showTime();  
}

void initdht1()
{
    dht1.begin();  //jason
}





void initRTC()
{
  Wire.begin();
  RTC.begin();
  if (!RTC.isrunning())
  {
    //Serial.println(F("[WARNING] RTC is NOT running!"));
    //RTC.adjust(DateTime(__DATE__, __TIME__));
    //RTC.adjust(DateTime("Sep 12 2015", "17:00:00"));
    RTC.adjust(DateTime(0l));
  }
}

// Fill h and m variables with the current time from the RTC
void getRTCtime()
{
    DateTime now = RTC.now();  
    h = now.hour();
    m = now.minute();
    s = now.second();
//    t = now.tempC();

}


// Update time in the RTC using h and m variables Brett added s variable. s is reset to 30 when 30 second sync pulse received
void updateRTCtime()
{
  
  // synchronised = 1; // now called by showSync()
    DateTime newDateTime = DateTime(
      2020, 9, 12,
      h, m,
      s, 32, 0.0); 
    RTC.adjust(newDateTime); 
   
}




// Show the time with the currently selected clock mode
void showTime()
{
  clearFrame();
  
  switch (displayMode)
  {
    case MODE_WORD_CLOCK:
      showTimeWords();
      break;
    case MODE_DIGITAL_CLOCK:
      showTimeDigits();
      break;
    case MODE_ANALOG_CLOCK:
      showTimeAnalog();
      break;
  }
}



// Show the current time on the display using digits
void showTimeDigits()
{

  byte hTenths = h / 10; //tenth hours
  byte hUnits = h % 10; //unit
  byte mTenths = m / 10;
  byte mUnits = m % 10;
  
  // Print the hour (blink if setting hour)
  if (timeMode == TIME_MODE_NORMAL ||
      timeMode == TIME_MODE_SETTING_HOUR && blink || 
      timeMode == TIME_MODE_SETTING_MINUTE)
  {
    addCharToFrame(0           ,0            , hTenths);
    addCharToFrame(CHAR_WIDTH+1,0            , hUnits);
  }
  
  // Print the minute (blink if setting minute)
  if (timeMode == TIME_MODE_NORMAL ||
      timeMode == TIME_MODE_SETTING_HOUR ||
      timeMode == TIME_MODE_SETTING_MINUTE && blink)
  {
    addCharToFrame(0           ,CHAR_HEIGHT+1, mTenths);
    addCharToFrame(CHAR_WIDTH+1,CHAR_HEIGHT+1, mUnits);
  }
  
  // Draw blinking colon
  //frame[2][13] = blink;
  //frame[4][13] = blink;  
  setFrame(frame2,2,13,blink);
  setFrame(frame2,4,13,blink);
  blink = !blink;

  // Seconds Display on bottom row
  addWordToFrame(w_seconds[ int( s / 10 ) ] ); 
  addWordToFrame(w_seconds[ int( s % 10 ) + 6 ]);
  /*  if(s == 0)
    {
      addWordToFrame(w_seconds[0]);
      addWordToFrame(w_seconds[6]);
    }

    if(s == 1)
    {
      addWordToFrame(w_seconds[0]);
      addWordToFrame(w_seconds[7]);
    }
    
    
    if(s == 2)
    {
      addWordToFrame(w_seconds[0]);
      addWordToFrame(w_seconds[8]);
    }

    if(s == 3)
    {
      addWordToFrame(w_seconds[0]);
      addWordToFrame(w_seconds[9]);
    }


    if(s == 4)
    {
      addWordToFrame(w_seconds[0]);
      addWordToFrame(w_seconds[10]);
    }


    if(s == 5)
    {
      addWordToFrame(w_seconds[0]);
      addWordToFrame(w_seconds[11]);
    }


     if(s == 6)
    {
      addWordToFrame(w_seconds[0]);
      addWordToFrame(w_seconds[12]);
    }

    if(s == 7)
    {
      addWordToFrame(w_seconds[0]);
      addWordToFrame(w_seconds[13]);
    }

    if(s == 8)
    {
      addWordToFrame(w_seconds[0]);
      addWordToFrame(w_seconds[14]);
    }


    if(s == 9)
    {
      addWordToFrame(w_seconds[0]);
      addWordToFrame(w_seconds[15]);
    }



    //------------------------------

    
    if(s == 10)
    {
      addWordToFrame(w_seconds[1]);
      addWordToFrame(w_seconds[6]);
    }

    if(s == 11)
    {
      addWordToFrame(w_seconds[1]);
      addWordToFrame(w_seconds[7]);
    }
    
    
    if(s == 12)
    {
      addWordToFrame(w_seconds[1]);
      addWordToFrame(w_seconds[8]);
    }

    if(s == 13)
    {
      addWordToFrame(w_seconds[1]);
      addWordToFrame(w_seconds[9]);
    }


    if(s == 14)
    {
      addWordToFrame(w_seconds[1]);
      addWordToFrame(w_seconds[10]);
    }


    if(s == 15)
    {
      addWordToFrame(w_seconds[1]);
      addWordToFrame(w_seconds[11]);
    }


     if(s == 16)
    {
      addWordToFrame(w_seconds[1]);
      addWordToFrame(w_seconds[12]);
    }

    if(s == 17)
    {
      addWordToFrame(w_seconds[1]);
      addWordToFrame(w_seconds[13]);
    }

    if(s == 18)
    {
      addWordToFrame(w_seconds[1]);
      addWordToFrame(w_seconds[14]);
    }


    if(s == 19)
    {
      addWordToFrame(w_seconds[1]);
      addWordToFrame(w_seconds[15]);
    }

     //------------------------------

    
    if(s == 20)
    {
      addWordToFrame(w_seconds[2]);
      addWordToFrame(w_seconds[6]);
    }

    if(s == 21)
    {
      addWordToFrame(w_seconds[2]);
      addWordToFrame(w_seconds[7]);
    }
    
    
    if(s == 22)
    {
      addWordToFrame(w_seconds[2]);
      addWordToFrame(w_seconds[8]);
    }

    if(s == 23)
    {
      addWordToFrame(w_seconds[2]);
      addWordToFrame(w_seconds[9]);
    }


    if(s == 24)
    {
      addWordToFrame(w_seconds[2]);
      addWordToFrame(w_seconds[10]);
    }


    if(s == 25)
    {
      addWordToFrame(w_seconds[2]);
      addWordToFrame(w_seconds[11]);
    }


     if(s == 26)
    {
      addWordToFrame(w_seconds[2]);
      addWordToFrame(w_seconds[12]);
    }

    if(s == 27)
    {
      addWordToFrame(w_seconds[2]);
      addWordToFrame(w_seconds[13]);
    }

    if(s == 28)
    {
      addWordToFrame(w_seconds[2]);
      addWordToFrame(w_seconds[14]);
    }


    if(s == 29)
    {
      addWordToFrame(w_seconds[2]);
      addWordToFrame(w_seconds[15]);
    }


     //------------------------------

    
    if(s == 30)
    {
      addWordToFrame(w_seconds[3]);
      addWordToFrame(w_seconds[6]);
    }

    if(s == 31)
    {
      addWordToFrame(w_seconds[3]);
      addWordToFrame(w_seconds[7]);
    }
    
    
    if(s == 32)
    {
      addWordToFrame(w_seconds[3]);
      addWordToFrame(w_seconds[8]);
    }

    if(s == 33)
    {
      addWordToFrame(w_seconds[3]);
      addWordToFrame(w_seconds[9]);
    }


    if(s == 34)
    {
      addWordToFrame(w_seconds[3]);
      addWordToFrame(w_seconds[10]);
    }


    if(s == 35)
    {
      addWordToFrame(w_seconds[3]);
      addWordToFrame(w_seconds[11]);
    }


     if(s == 36)
    {
      addWordToFrame(w_seconds[3]);
      addWordToFrame(w_seconds[12]);
    }

    if(s == 37)
    {
      addWordToFrame(w_seconds[3]);
      addWordToFrame(w_seconds[13]);
    }

    if(s == 38)
    {
      addWordToFrame(w_seconds[3]);
      addWordToFrame(w_seconds[14]);
    }


    if(s == 39)
    {
      addWordToFrame(w_seconds[3]);
      addWordToFrame(w_seconds[15]);
    }



      //------------------------------

    
    if(s == 40)
    {
      addWordToFrame(w_seconds[4]);
      addWordToFrame(w_seconds[6]);
    }

    if(s == 41)
    {
      addWordToFrame(w_seconds[4]);
      addWordToFrame(w_seconds[7]);
    }
    
    
    if(s == 42)
    {
      addWordToFrame(w_seconds[4]);
      addWordToFrame(w_seconds[8]);
    }

    if(s == 43)
    {
      addWordToFrame(w_seconds[4]);
      addWordToFrame(w_seconds[9]);
    }


    if(s == 44)
    {
      addWordToFrame(w_seconds[4]);
      addWordToFrame(w_seconds[10]);
    }


    if(s == 45)
    {
      addWordToFrame(w_seconds[4]);
      addWordToFrame(w_seconds[11]);
    }


     if(s == 46)
    {
      addWordToFrame(w_seconds[4]);
      addWordToFrame(w_seconds[12]);
    }

    if(s == 47)
    {
      addWordToFrame(w_seconds[4]);
      addWordToFrame(w_seconds[13]);
    }

    if(s == 48)
    {
      addWordToFrame(w_seconds[4]);
      addWordToFrame(w_seconds[14]);
    }


    if(s == 49)
    {
      addWordToFrame(w_seconds[4]);
      addWordToFrame(w_seconds[15]);
    }
    

      //------------------------------

    
    if(s == 50)
    {
      addWordToFrame(w_seconds[5]);
      addWordToFrame(w_seconds[6]);
    }

    if(s == 51)
    {
      addWordToFrame(w_seconds[5]);
      addWordToFrame(w_seconds[7]);
    }
    
    
    if(s == 52)
    {
      addWordToFrame(w_seconds[5]);
      addWordToFrame(w_seconds[8]);
    }

    if(s == 53)
    {
      addWordToFrame(w_seconds[5]);
      addWordToFrame(w_seconds[9]);
    }


    if(s == 54)
    {
      addWordToFrame(w_seconds[5]);
      addWordToFrame(w_seconds[10]);
    }


    if(s == 55)
    {
      addWordToFrame(w_seconds[5]);
      addWordToFrame(w_seconds[11]);
    }


     if(s == 56)
    {
      addWordToFrame(w_seconds[5]);
      addWordToFrame(w_seconds[12]);
    }

    if(s == 57)
    {
      addWordToFrame(w_seconds[5]);
      addWordToFrame(w_seconds[13]);
    }

    if(s == 58)
    {
      addWordToFrame(w_seconds[5]);
      addWordToFrame(w_seconds[14]);
    }


    if(s == 59)
    {
      addWordToFrame(w_seconds[5]);
      addWordToFrame(w_seconds[15]);
    }
    */

  updateDisplay();
}



// Show the current time on the display using words
void showTimeWords()
{
  byte h2 = h;

 /* 
 // Show "THE TIME IS"
  addWordToFrame(w_the);
  addWordToFrame(w_time);
  addWordToFrame(w_is);

*/

  
  // Minutes
  if (m == 0) {
    
    if (h == 0) {
      addWordToFrame(w_hours[11]);
      addWordToFrame(w_oclock);
      addWordToFrame(w_at);
      addWordToFrame(w_night_ampm);
      // Show "THE TIME IS"
  addWordToFrame(w_the);
  addWordToFrame(w_time);
  addWordToFrame(w_is);
      
      
    } else if (h == 12) {
       addWordToFrame(w_hours[11]);
      addWordToFrame(w_oclock);
      addWordToFrame(w_in);
      addWordToFrame(w_the_ampm);
      addWordToFrame(w_afternoon_ampm);
      // Show "THE TIME IS"
  addWordToFrame(w_the);
  addWordToFrame(w_time);
  addWordToFrame(w_is);
    } else {
      // Show "THE TIME IS"
  addWordToFrame(w_the);
  addWordToFrame(w_time);
  addWordToFrame(w_is);
      addWordToFrame(w_oclock);
    }

  } else {
  
    if (m <= 20) {
      addWordToFrame(w_minutes[m - 1]);
      // Show "THE TIME IS"
  addWordToFrame(w_the);
  addWordToFrame(w_time);
  addWordToFrame(w_is);
    } else if (m < 30) {
      // Show "THE TIME IS"
  addWordToFrame(w_the);
  addWordToFrame(w_time);
  addWordToFrame(w_is);
      addWordToFrame(w_minutes[19]); // twenty
      addWordToFrame(w_minutes[m - 21]);
    } else if (m == 30) {
      addWordToFrame(w_half);
      // Show "THE TIME IS"
  addWordToFrame(w_the);
  addWordToFrame(w_time);
  addWordToFrame(w_is);
    } else if (m < 40) {
      addWordToFrame(w_minutes[19]); // twenty
      addWordToFrame(w_minutes[60 - m - 21]);
      // Show "THE TIME IS"
  addWordToFrame(w_the);
  addWordToFrame(w_time);
  addWordToFrame(w_is);
    } else {
      addWordToFrame(w_minutes[60 - m - 1]);
      // Show "THE TIME IS"
  addWordToFrame(w_the);
  addWordToFrame(w_time);
  addWordToFrame(w_is);
    }
 
    if(m <= 30) {
      addWordToFrame(w_past);
      // Show "THE TIME IS"
  addWordToFrame(w_the);
  addWordToFrame(w_time);
  addWordToFrame(w_is);
    } else {
      addWordToFrame(w_to);
      // Show "THE TIME IS"
  addWordToFrame(w_the);
  addWordToFrame(w_time);
  addWordToFrame(w_is);
      ++h2;
    }
    
  } 
  
  if(!(m ==0 && (h == 0 || h == 12))) {
  
    // Hours
    if(h2 == 0) {
      addWordToFrame(w_hours[11]);
      // Show "THE TIME IS"
  addWordToFrame(w_the);
  addWordToFrame(w_time);
  addWordToFrame(w_is);
    } else if (h2 <= 12) {
      addWordToFrame(w_hours[h2 - 1]);
      // Show "THE TIME IS"
  addWordToFrame(w_the);
  addWordToFrame(w_time);
  addWordToFrame(w_is);
    } else {
      addWordToFrame(w_hours[h2 - 13]);
      // Show "THE TIME IS"
  addWordToFrame(w_the);
  addWordToFrame(w_time);
  addWordToFrame(w_is);
    }


   // Minute & Minutes add Minutes after the minute number

   if( (m == 1) || (m ==59) )
   {
     addWordToFrame(w_minute);
     // Show "THE TIME IS"
  addWordToFrame(w_the);
  addWordToFrame(w_time);
  addWordToFrame(w_is);
   }


  // No mintues name display 5,10,15 etc mins past or to the hour
   if ( (m > 1 && m < 5) || (m > 5 && m < 10) || (m > 10 && m < 15) || (m > 15 && m < 20 ) || (m > 20 && m  <25) || (m > 25 && m < 30) || (m > 30 && m < 35) ||  (m > 35 && m < 40) || (m > 40 && m < 45  )|| (m > 45 && m < 50) || (m > 50 && m < 55) || (m > 55 && m < 59))
   {
    addWordToFrame(w_minute);
    addWordToFrame(w_s);
   }
   
    // Time of day
   // if(h < 6) {
      if(h < 1) { 
      addWordToFrame(w_at);
      addWordToFrame(w_night_ampm);
      // Show "THE TIME IS"
  addWordToFrame(w_the);
  addWordToFrame(w_time);
  addWordToFrame(w_is);
    } else if(h < 12) {
      addWordToFrame(w_in);
      addWordToFrame(w_the_ampm);
      addWordToFrame(w_morning_ampm);
      // Show "THE TIME IS"
  addWordToFrame(w_the);
  addWordToFrame(w_time);
  addWordToFrame(w_is);
    } else if(h < 18) {
      addWordToFrame(w_in);
      addWordToFrame(w_the_ampm);
      addWordToFrame(w_afternoon_ampm);
      // Show "THE TIME IS"
  addWordToFrame(w_the);
  addWordToFrame(w_time);
  addWordToFrame(w_is);
    } else if(h >= 18 &&  h < 21) {
      addWordToFrame(w_in);
      addWordToFrame(w_the_ampm);
      addWordToFrame(w_evening_ampm);
      // Show "THE TIME IS"
  addWordToFrame(w_the);
  addWordToFrame(w_time);
  addWordToFrame(w_is);
    } else {
      addWordToFrame(w_at);
      addWordToFrame(w_night_ampm);
      // Show "THE TIME IS"
  addWordToFrame(w_the);
  addWordToFrame(w_time);
  addWordToFrame(w_is);
    }


    // Minutes Quarter add "a" to quarter past and quarter to
    if (m == 15 or m == 45)
    {
      addWordToFrame(w_a);
      // Show "THE TIME IS"
  addWordToFrame(w_the);
  addWordToFrame(w_time);
  addWordToFrame(w_is);
    }

  }
  
// Seconds Display on bottom row
   addWordToFrame(w_seconds[ int( s / 10 ) ] ); 
   addWordToFrame(w_seconds[ int( s % 10 ) + 6 ]);
   /* if(s == 0)
    {
      addWordToFrame(w_seconds[0]);
      addWordToFrame(w_seconds[6]);
    }

    if(s == 1)
    {
      addWordToFrame(w_seconds[0]);
      addWordToFrame(w_seconds[7]);
    }
    
    
    if(s == 2)
    {
      addWordToFrame(w_seconds[0]);
      addWordToFrame(w_seconds[8]);
    }

    if(s == 3)
    {
      addWordToFrame(w_seconds[0]);
      addWordToFrame(w_seconds[9]);
    }


    if(s == 4)
    {
      addWordToFrame(w_seconds[0]);
      addWordToFrame(w_seconds[10]);
    }


    if(s == 5)
    {
      addWordToFrame(w_seconds[0]);
      addWordToFrame(w_seconds[11]);
    }


     if(s == 6)
    {
      addWordToFrame(w_seconds[0]);
      addWordToFrame(w_seconds[12]);
    }

    if(s == 7)
    {
      addWordToFrame(w_seconds[0]);
      addWordToFrame(w_seconds[13]);
    }

    if(s == 8)
    {
      addWordToFrame(w_seconds[0]);
      addWordToFrame(w_seconds[14]);
    }


    if(s == 9)
    {
      addWordToFrame(w_seconds[0]);
      addWordToFrame(w_seconds[15]);
    }



    //------------------------------

    
    if(s == 10)
    {
      addWordToFrame(w_seconds[1]);
      addWordToFrame(w_seconds[6]);
    }

    if(s == 11)
    {
      addWordToFrame(w_seconds[1]);
      addWordToFrame(w_seconds[7]);
    }
    
    
    if(s == 12)
    {
      addWordToFrame(w_seconds[1]);
      addWordToFrame(w_seconds[8]);
    }

    if(s == 13)
    {
      addWordToFrame(w_seconds[1]);
      addWordToFrame(w_seconds[9]);
    }


    if(s == 14)
    {
      addWordToFrame(w_seconds[1]);
      addWordToFrame(w_seconds[10]);
    }


    if(s == 15)
    {
      addWordToFrame(w_seconds[1]);
      addWordToFrame(w_seconds[11]);
    }


     if(s == 16)
    {
      addWordToFrame(w_seconds[1]);
      addWordToFrame(w_seconds[12]);
    }

    if(s == 17)
    {
      addWordToFrame(w_seconds[1]);
      addWordToFrame(w_seconds[13]);
    }

    if(s == 18)
    {
      addWordToFrame(w_seconds[1]);
      addWordToFrame(w_seconds[14]);
    }


    if(s == 19)
    {
      addWordToFrame(w_seconds[1]);
      addWordToFrame(w_seconds[15]);
    }

     //------------------------------

    
    if(s == 20)
    {
      addWordToFrame(w_seconds[2]);
      addWordToFrame(w_seconds[6]);
    }

    if(s == 21)
    {
      addWordToFrame(w_seconds[2]);
      addWordToFrame(w_seconds[7]);
    }
    
    
    if(s == 22)
    {
      addWordToFrame(w_seconds[2]);
      addWordToFrame(w_seconds[8]);
    }

    if(s == 23)
    {
      addWordToFrame(w_seconds[2]);
      addWordToFrame(w_seconds[9]);
    }


    if(s == 24)
    {
      addWordToFrame(w_seconds[2]);
      addWordToFrame(w_seconds[10]);
    }


    if(s == 25)
    {
      addWordToFrame(w_seconds[2]);
      addWordToFrame(w_seconds[11]);
    }


     if(s == 26)
    {
      addWordToFrame(w_seconds[2]);
      addWordToFrame(w_seconds[12]);
    }

    if(s == 27)
    {
      addWordToFrame(w_seconds[2]);
      addWordToFrame(w_seconds[13]);
    }

    if(s == 28)
    {
      addWordToFrame(w_seconds[2]);
      addWordToFrame(w_seconds[14]);
    }


    if(s == 29)
    {
      addWordToFrame(w_seconds[2]);
      addWordToFrame(w_seconds[15]);
    }


     //------------------------------

    
    if(s == 30)
    {
      addWordToFrame(w_seconds[3]);
      addWordToFrame(w_seconds[6]);
    }

    if(s == 31)
    {
      addWordToFrame(w_seconds[3]);
      addWordToFrame(w_seconds[7]);
    }
    
    
    if(s == 32)
    {
      addWordToFrame(w_seconds[3]);
      addWordToFrame(w_seconds[8]);
    }

    if(s == 33)
    {
      addWordToFrame(w_seconds[3]);
      addWordToFrame(w_seconds[9]);
    }


    if(s == 34)
    {
      addWordToFrame(w_seconds[3]);
      addWordToFrame(w_seconds[10]);
    }


    if(s == 35)
    {
      addWordToFrame(w_seconds[3]);
      addWordToFrame(w_seconds[11]);
    }


     if(s == 36)
    {
      addWordToFrame(w_seconds[3]);
      addWordToFrame(w_seconds[12]);
    }

    if(s == 37)
    {
      addWordToFrame(w_seconds[3]);
      addWordToFrame(w_seconds[13]);
    }

    if(s == 38)
    {
      addWordToFrame(w_seconds[3]);
      addWordToFrame(w_seconds[14]);
    }


    if(s == 39)
    {
      addWordToFrame(w_seconds[3]);
      addWordToFrame(w_seconds[15]);
    }



      //------------------------------

    
    if(s == 40)
    {
      addWordToFrame(w_seconds[4]);
      addWordToFrame(w_seconds[6]);
    }

    if(s == 41)
    {
      addWordToFrame(w_seconds[4]);
      addWordToFrame(w_seconds[7]);
    }
    
    
    if(s == 42)
    {
      addWordToFrame(w_seconds[4]);
      addWordToFrame(w_seconds[8]);
    }

    if(s == 43)
    {
      addWordToFrame(w_seconds[4]);
      addWordToFrame(w_seconds[9]);
    }


    if(s == 44)
    {
      addWordToFrame(w_seconds[4]);
      addWordToFrame(w_seconds[10]);
    }


    if(s == 45)
    {
      addWordToFrame(w_seconds[4]);
      addWordToFrame(w_seconds[11]);
    }


     if(s == 46)
    {
      addWordToFrame(w_seconds[4]);
      addWordToFrame(w_seconds[12]);
    }

    if(s == 47)
    {
      addWordToFrame(w_seconds[4]);
      addWordToFrame(w_seconds[13]);
    }

    if(s == 48)
    {
      addWordToFrame(w_seconds[4]);
      addWordToFrame(w_seconds[14]);
    }


    if(s == 49)
    {
      addWordToFrame(w_seconds[4]);
      addWordToFrame(w_seconds[15]);
    }
    

      //------------------------------

    
    if(s == 50)
    {
      addWordToFrame(w_seconds[5]);
      addWordToFrame(w_seconds[6]);
    }

    if(s == 51)
    {
      addWordToFrame(w_seconds[5]);
      addWordToFrame(w_seconds[7]);
    }
    
    
    if(s == 52)
    {
      addWordToFrame(w_seconds[5]);
      addWordToFrame(w_seconds[8]);
    }

    if(s == 53)
    {
      addWordToFrame(w_seconds[5]);
      addWordToFrame(w_seconds[9]);
    }


    if(s == 54)
    {
      addWordToFrame(w_seconds[5]);
      addWordToFrame(w_seconds[10]);
    }


    if(s == 55)
    {
      addWordToFrame(w_seconds[5]);
      addWordToFrame(w_seconds[11]);
    }


     if(s == 56)
    {
      addWordToFrame(w_seconds[5]);
      addWordToFrame(w_seconds[12]);
    }

    if(s == 57)
    {
      addWordToFrame(w_seconds[5]);
      addWordToFrame(w_seconds[13]);
    }

    if(s == 58)
    {
      addWordToFrame(w_seconds[5]);
      addWordToFrame(w_seconds[14]);
    }


    if(s == 59)
    {
      addWordToFrame(w_seconds[5]);
      addWordToFrame(w_seconds[15]);
    }
    */



 {

  // Temp Display on second bottom row
  addWordToFrame(w_and);
  addWordToFrame(w_deg);
  addWordToFrame(w_temp[ int ( tem / 10 ) ]); 
  addWordToFrame(w_temp[ int ( tem % 10 ) + 5 ]);
  /*  if(tem == 0)
    {
      addWordToFrame(w_temp[5]);
    }

    if(tem == 1)
    {
      addWordToFrame(w_temp[6]);
    }
    
    
    if(tem == 2)
    {
      addWordToFrame(w_temp[7]);
    }

    if(tem == 3)
    {
      addWordToFrame(w_temp[8]);
    }


    if(tem == 4)
    {
      addWordToFrame(w_temp[9]);
    }


    if(tem == 5)
    {
      addWordToFrame(w_temp[10]);
    }


     if(tem == 6)
    {
      addWordToFrame(w_temp[11]);
    }

    if(tem == 7)
    {
      addWordToFrame(w_temp[12]);
    }

    if(tem == 8)
    {
      addWordToFrame(w_temp[13]);
    }


    if(tem == 9)
    {
      addWordToFrame(w_temp[14]);
    }



    //------------------------------

    
    if(tem == 10)
    {
      addWordToFrame(w_temp[1]);
      addWordToFrame(w_temp[5]);
    }

    if(tem == 11)
    {
      addWordToFrame(w_temp[1]);
      addWordToFrame(w_temp[6]);
    }
    
    
    if(tem == 12)
    {
      addWordToFrame(w_temp[1]);
      addWordToFrame(w_temp[7]);
    }

    if(tem == 13)
    {
      addWordToFrame(w_temp[1]);
      addWordToFrame(w_temp[8]);
    }


    if(tem == 14)
    {
      addWordToFrame(w_temp[1]);
      addWordToFrame(w_temp[9]);
    }


    if(tem == 15)
    {
      addWordToFrame(w_temp[1]);
      addWordToFrame(w_temp[10]);
    }


     if(tem == 16)
    {
      addWordToFrame(w_temp[1]);
      addWordToFrame(w_temp[11]);
    }

    if(tem == 17)
    {
      addWordToFrame(w_temp[1]);
      addWordToFrame(w_temp[12]);
    }

    if(tem == 18)
    {
      addWordToFrame(w_temp[1]);
      addWordToFrame(w_temp[13]);
    }


    if(tem == 19)
    {
      addWordToFrame(w_temp[1]);
      addWordToFrame(w_temp[14]);
    }

     //------------------------------

    
    if(tem == 20)
    {
      addWordToFrame(w_temp[2]);
      addWordToFrame(w_temp[5]);
    }

    if(tem == 21)
    {
      addWordToFrame(w_temp[2]);
      addWordToFrame(w_temp[6]);
    }
    
    
    if(tem == 22)
    {
      addWordToFrame(w_temp[2]);
      addWordToFrame(w_temp[7]);
    }

    if(tem == 23)
    {
      addWordToFrame(w_temp[2]);
      addWordToFrame(w_temp[8]);
    }


    if(tem == 24)
    {
      addWordToFrame(w_temp[2]);
      addWordToFrame(w_temp[9]);
    }


    if(tem == 25)
    {
      addWordToFrame(w_temp[2]);
      addWordToFrame(w_temp[10]);
    }


     if(tem == 26)
    {
      addWordToFrame(w_temp[2]);
      addWordToFrame(w_temp[11]);
    }

    if(tem == 27)
    {
      addWordToFrame(w_temp[2]);
      addWordToFrame(w_temp[12]);
    }

    if(tem == 28)
    {
      addWordToFrame(w_temp[2]);
      addWordToFrame(w_temp[13]);
    }


    if(tem == 29)
    {
      addWordToFrame(w_temp[2]);
      addWordToFrame(w_temp[14]);
    }


     //------------------------------

    
    if(tem == 30)
    {
      addWordToFrame(w_temp[3]);
      addWordToFrame(w_temp[5]);
    }

    if(tem == 31)
    {
      addWordToFrame(w_temp[3]);
      addWordToFrame(w_temp[6]);
    }
    
    
    if(tem == 32)
    {
      addWordToFrame(w_temp[3]);
      addWordToFrame(w_temp[7]);
    }

    if(tem == 33)
    {
      addWordToFrame(w_temp[3]);
      addWordToFrame(w_temp[8]);
    }


    if(tem == 34)
    {
      addWordToFrame(w_temp[3]);
      addWordToFrame(w_temp[9]);
    }


    if(tem == 35)
    {
      addWordToFrame(w_temp[3]);
      addWordToFrame(w_temp[10]);
    }


     if(tem == 36)
    {
      addWordToFrame(w_temp[3]);
      addWordToFrame(w_temp[11]);
    }

    if(tem == 37)
    {
      addWordToFrame(w_temp[3]);
      addWordToFrame(w_temp[12]);
    }

    if(tem == 38)
    {
      addWordToFrame(w_temp[3]);
      addWordToFrame(w_temp[13]);
    }


    if(tem == 39)
    {
      addWordToFrame(w_temp[3]);
      addWordToFrame(w_temp[14]);
    }



      //------------------------------

    
    if(tem == 40)
    {
      addWordToFrame(w_temp[4]);
      addWordToFrame(w_temp[5]);
    }

    if(tem == 41)
    {
      addWordToFrame(w_temp[4]);
      addWordToFrame(w_temp[6]);
    }
    
    
    if(tem == 42)
    {
      addWordToFrame(w_temp[4]);
      addWordToFrame(w_temp[7]);
    }

    if(tem == 43)
    {
      addWordToFrame(w_temp[4]);
      addWordToFrame(w_temp[8]);
    }


    if(tem == 44)
    {
      addWordToFrame(w_temp[4]);
      addWordToFrame(w_temp[9]);
    }


    if(tem == 45)
    {
      addWordToFrame(w_temp[4]);
      addWordToFrame(w_temp[10]);
    }


     if(tem == 46)
    {
      addWordToFrame(w_temp[4]);
      addWordToFrame(w_temp[11]);
    }

    if(tem == 47)
    {
      addWordToFrame(w_temp[4]);
      addWordToFrame(w_temp[12]);
    }

    if(tem == 48)
    {
      addWordToFrame(w_temp[4]);
      addWordToFrame(w_temp[13]);
    }


    if(tem == 49)
    {
      addWordToFrame(w_temp[4]);
      addWordToFrame(w_temp[14]);
    }

    */

 updateDisplay();
}
//if (tem <= 16) {
//    addWordToFrame(w_cold);
//  } else if (tem <= 25) {
//    addWordToFrame(w_cool);
//  } else if (tem <= 30) {
//    addWordToFrame(w_warm);
//  } else {
//    addWordToFrame(w_hot);
//  }
//  }
  
  tem = dht1.readTemperature(); //jason
  

}

// END ENGLISH VERSION
